@@ -25,7 +25,7 @@ package Spreadsheet::Read;
 use strict;
 use warnings;
 
-our $VERSION = "0.64";
+our $VERSION = "0.65";
 sub  Version { $VERSION }
 
 use Carp;
@@ -47,7 +47,6 @@ my @parsers = (
     [ xls  => "Spreadsheet::ParseExcel",		"0.34"		],
     [ xlsx => "Spreadsheet::ParseXLSX",			"0.13"		],
     [ xlsx => "Spreadsheet::XLSX",			"0.13"		],
-    [ xlsx => "Spreadsheet::XLSX::Reader::LibXML",	"v9.99.99"	],
     [ prl  => "Spreadsheet::Perl",			""		],
 
     # Helper modules
@@ -339,7 +338,7 @@ sub _xlsx_libxml
 		$wks->{Cells}[$r][$c] = $cell;
 		}
 	    }
-	# Spreadsheet::XLSX::Reader::LibXML returns all other cells in range as undef
+	# Spreadsheet::XLSX::Reader::LibXML returned all other cells in range as undef
 	foreach my $mm (values %mm) {
 	    my @mr = sort keys %$mm;
 	    foreach my $rc (@mr) {
@@ -347,10 +346,6 @@ sub _xlsx_libxml
 		}
 	    }
 	}
-    *Spreadsheet::XLSX::Reader::LibXML::Cell::Value = sub {
-	my $cell = shift;
-	$cell->value;
-	};
     *WorksheetInstance::get_merged_areas = sub {
 	my $wi = shift or return;
 	my $mm = eval { $wi->_get_merge_map } ||
@@ -428,7 +423,7 @@ sub ReadData
 
 	my $label = $io_fil ? $txt : "IO";
 
-	$debug and print STDERR "Opening CSV $label\n";
+	$debug and print STDERR "Opening CSV $label using $can{csv}-", $can{csv}->VERSION, "\n";
 
 	my @data = (
 	    {	type	=> "csv",
@@ -536,7 +531,7 @@ sub ReadData
 	my $parser = $can{lc $parse_type} or
 	    croak "Parser for $parse_type is not installed";
 	my $xlsx_libxml = $parser =~ m/LibXML$/;
-	$debug and print STDERR "Opening $parse_type \$txt\n";
+	$debug and print STDERR "Opening $parse_type $txt using $parser-", $can{lc $parse_type}->VERSION, "\n";
 	my $oBook = eval {
 	    $io_ref
 	      ? $parse_type eq "XLSX"
@@ -557,6 +552,14 @@ sub ReadData
 	    }
 	$debug > 8 and _dump (oBook => $oBook);
 
+	# WorkBook keys:
+	# aColor         _CurSheet      Format         SheetCount
+	# ActiveSheet    _CurSheet_     FormatStr      _skip_chart
+	# Author         File           NotSetCell     _string_contin
+	# BIFFVersion    Flg1904        Object         Version
+	# _buffer        FmtClass       PkgStr         Worksheet
+	# CellHandler    Font           _previous_info
+
 	$xlsx_libxml and _xlsx_libxml ($oBook);
 
 	my @data = ( {
@@ -567,6 +570,7 @@ sub ReadData
 	    sheets	=> $oBook->{SheetCount} || 0,
 	    sheet	=> {},
 	    } );
+	# $debug and $data[0]{_parser} = $oBook;
 	# Overrule the default date format strings
 	my %def_fmt = (
 	    0x0E	=> lc $opt{dtfmt},	# m-d-yy
@@ -577,11 +581,9 @@ sub ReadData
 	$oBook->{FormatStr}{$_} = $def_fmt{$_} for keys %def_fmt;
 	my $oFmt = $parse_type eq "XLSX"
 	    ? $can{xlsx} =~ m/::XLSX$/
-	    ? Spreadsheet::XLSX::Fmt2007->new
-	    : $can{xlsx} =~ m/::XLSX/
-	    ? Spreadsheet::XLSX::Reader::LibXML::FmtDefault->new
-	    : Spreadsheet::ParseExcel::FmtDefault->new
-	    : Spreadsheet::ParseExcel::FmtDefault->new;
+		? Spreadsheet::XLSX::Fmt2007->new
+		: Spreadsheet::ParseExcel::FmtDefault->new
+	    :     Spreadsheet::ParseExcel::FmtDefault->new;
 
 	$debug and print STDERR "\t$data[0]{sheets} sheets\n";
 	foreach my $oWkS (@{$oBook->{Worksheet}}) {
@@ -594,6 +596,7 @@ sub ReadData
 		attr	=> [],
 		merged  => [],
 		);
+	    # $debug and $sheet{_parser} = $oWkS;
 	    defined $sheet{label}  or  $sheet{label}  = "-- unlabeled --";
 	    exists $oWkS->{MinRow} and $sheet{minrow} = $oWkS->{MinRow} + 1;
 	    exists $oWkS->{MaxRow} and $sheet{maxrow} = $oWkS->{MaxRow} + 1;
@@ -607,7 +610,24 @@ sub ReadData
 		@{$oWkS->get_merged_areas || []}];
 	    my $sheet_idx = 1 + @data;
 	    $debug and print STDERR "\tSheet $sheet_idx '$sheet{label}' $sheet{maxrow} x $sheet{maxcol}\n";
+	    # Sheet keys:
+	    # _Book          FooterMargin   MinCol         RightMargin
+	    # BottomMargin   FooterMergin   MinRow         RightMergin
+	    # BottomMergin   HCenter        Name           RowHeight
+	    # Cells          Header         NoColor        RowHidden
+	    # ColFmtNo       HeaderMargin   NoOrient       Scale
+	    # ColHidden      HeaderMergin   NoPls          SheetHidden
+	    # ColWidth       Kind           Notes          _SheetNo
+	    # Copis          Landscape      PageFit        SheetType
+	    # DefColWidth    LeftMargin     PageStart      SheetVersion
+	    # DefRowHeight   LeftMergin     PaperSize      TopMargin
+	    # Draft          LeftToRight    _Pos           TopMergin
+	    # FitHeight      MaxCol         PrintGrid      UsePage
+	    # FitWidth       MaxRow         PrintHeaders   VCenter
+	    # Footer         MergedArea     Res            VRes
 	    if (exists $oWkS->{MinRow}) {
+		my $hiddenRows = $oWkS->{RowHidden} || [];
+		my $hiddenCols = $oWkS->{ColHidden} || [];
 		if ($opt{clip}) {
 		    my ($mr, $mc) = (-1, -1);
 		    foreach my $r ($oWkS->{MinRow} .. $sheet{maxrow}) {
@@ -649,14 +669,6 @@ sub ReadData
 			    }
 			exists $FmT->{Fill} or $FmT->{Fill} = [ 0 ];
 			exists $FmT->{Font} or $FmT->{Font} = undef;
-			if ($xlsx_libxml and
-			     ref $oWkC eq "Spreadsheet::XLSX::Reader::LibXML::Cell" and
-			     my $style = $oWkC->get_fill) {
-			    if (my $pf = $style->{patternFill}) {
-				#defined $pf->{fgColor}{indexed} and $FmT->{Font}{Color} =   $pf->{fgColor}{indexed};
-				#defined $pf->{bgColor}{indexed} and $FmT->{Fill}        = [ $pf->{bgColor}{indexed} ];
-				}
-			    }
 
 			unless (defined $fmt) {
 			    $fmt = $FmT->{FmtIdx}
@@ -695,7 +707,8 @@ sub ReadData
 				type    => lc $oWkC->{Type},
 				enc     => $oWkC->{Code},
 				merged  => (defined $oWkC->{Merged} ? $oWkC->{Merged} : $oWkC->is_merged) || 0,
-				hidden  => (defined $oWkC->{Hidden} ? $oWkC->{Hidden} : $FmT->{Hidden})   || 0,
+				hidden  => ($hiddenRows->[$r] || $hiddenCols->[$c] ? 1 :
+					    defined $oWkC->{Hidden} ? $oWkC->{Hidden} : $FmT->{Hidden})   || 0,
 				locked  => $FmT->{Lock}     || 0,
 				format  => $fmi,
 				halign  => [ undef, qw( left center right
@@ -791,20 +804,21 @@ sub ReadData
     if ($opt{parser} ? _parser ($opt{parser}) eq "sxc"
 		     : ($txt =~ m/^<\?xml/ or -f $txt)) {
 	$can{sxc} or croak "Spreadsheet::ReadSXC not installed";
+	my $using = "using $can{sxc}-" . $can{sxc}->VERSION;
 	my $sxc_options = { %parser_opts, OrderBySheet => 1 }; # New interface 0.20 and up
 	my $sxc;
 	   if ($txt =~ m/\.(sxc|ods)$/i) {
-	    $debug and print STDERR "Opening \U$1\E $txt\n";
+	    $debug and print STDERR "Opening \U$1\E $txt $using\n";
 	    $sxc = Spreadsheet::ReadSXC::read_sxc      ($txt, $sxc_options)	or  return;
 	    }
 	elsif ($txt =~ m/\.xml$/i) {
-	    $debug and print STDERR "Opening XML $txt\n";
+	    $debug and print STDERR "Opening XML $txt $using\n";
 	    $sxc = Spreadsheet::ReadSXC::read_xml_file ($txt, $sxc_options)	or  return;
 	    }
 	# need to test on pattern to prevent stat warning
 	# on filename with newline
 	elsif ($txt !~ m/^<\?xml/i and -f $txt) {
-	    $debug and print STDERR "Opening XML $txt\n";
+	    $debug and print STDERR "Opening XML $txt $using\n";
 	    open my $f, "<", $txt	or  return;
 	    local $/;
 	    $txt = <$f>;
@@ -1227,6 +1241,10 @@ is made to analyze and store field attributes like this:
 This has now been partially implemented, mainly for Excel, as the other
 parsers do not (yet) support all of that. YMMV.
 
+If a cell itself is not hidden, but the parser holds the information that
+either the row or the column (or both) the field is in is hidden, the flag
+is inherited into the cell attributes.
+
 =head3 Merged cells
 
 Note that only
@@ -1494,16 +1512,6 @@ but for new Microsoft Excel 2007+ files (.xlsx). They have the same API.
 This module uses L<XML::Twig|http://metacpan.org/release/XML-Twig> to parse the
 internal XML.
 
-=item Spreadsheet::XLSX::Reader::LibXML
-
-L<Spreadsheet::XLSX::Reader::LibXML|http://metacpan.org/release/Spreadsheet-XLSX-Reader-LibXML>
-is an alternative Microsoft 2007+ parser that uses
-L<XML::LibXML|http://metacpan.org/release/XML-LibXML> to parse the internal XML.
-
-Work in progress. Much is relying on undocumented internals. The author gave up
-on making this work, so it is not enabled by default. Feel free submit patches
-to make it work.
-
 =item Spreadsheet::XLSX
 
 See L<Spreadsheet::XLSX|http://metacpan.org/release/Spreadsheet-XLSX>
